@@ -1794,6 +1794,9 @@ void BweibDpCorScr_updateCP(gsl_vector *beta1,
     
     for(j = 0; j < u; j++)
     {
+        
+        n_jc = gsl_vector_get(cUniq_count, j);        
+        
         zetaA = pow(1/zeta0 + gsl_vector_get(cUniq_count, j), -1);
         
         rhoA = rho0 + gsl_vector_get(cUniq_count, j);
@@ -1892,7 +1895,6 @@ void BweibDpCorScr_updateCP(gsl_vector *beta1,
         }
         
         gsl_matrix_view Sigma_temp = gsl_matrix_submatrix(Sigma_all, 0, 3*jj, 3, 3);
-        gsl_vector_view mu_temp = gsl_vector_subvector(mu_all, 3*jj, 3);
         
         matrixInv(&Sigma_temp.matrix, invSigma_V);
         
